@@ -4,12 +4,7 @@ import asyncio
 import aiohttp
 import requests
 
-from python3_anticaptcha import (
-    create_task_url,
-    app_key,
-    get_sync_result,
-    get_async_result,
-)
+from python3_anticaptcha import app_key, create_task_url, get_sync_result, get_async_result
 
 
 class GeeTestTask:
@@ -32,9 +27,7 @@ class GeeTestTask:
         :param kwargs: Параметры для подключения к прокси. Подробнее в официальной документации или примерe  - anticaptcha_examples/anticaptcha_gee_test_task.py
 		"""
         if sleep_time < 10:
-            raise ValueError(
-                f"Param `sleep_time` must be greater than 10. U set - {sleep_time}"
-            )
+            raise ValueError(f"Param `sleep_time` must be greater than 10. U set - {sleep_time}")
         self.sleep_time = sleep_time
 
         # Пайлоад для создания задачи
@@ -65,16 +58,19 @@ class GeeTestTask:
         return True
 
     # Работа с капчёй
-    def captcha_handler(self, challenge: str) -> dict:
+    def captcha_handler(self, challenge: str, **kwargs) -> dict:
         """
 		Метод получает ссылку изображение для задания
 		:param challenge: Переменный токен который необходимо обновлять каждый раз перед созданием задачи
+        :param kwargs: Дополнительные параметры для `requests.post(....)`.
 		:return: Возвращает ответ сервера в виде JSON(ответ так же можно глянуть в документации антикапчи)
 		"""
         self.task_payload["task"].update({"challenge": challenge})
         # Отправляем на антикапча параметры фанкапич,
         # в результате получаем JSON ответ содержащий номер решаемой капчи
-        captcha_id = requests.post(create_task_url, json=self.task_payload).json()
+        captcha_id = requests.post(
+            create_task_url, json=self.task_payload, verify=False, **kwargs
+        ).json()
 
         # Проверка статуса создания задачи, если создано без ошибок - извлекаем ID задачи, иначе возвращаем ответ сервера
         if captcha_id["errorId"] == 0:
@@ -90,9 +86,7 @@ class GeeTestTask:
         else:
             # Ждем решения капчи
             time.sleep(self.sleep_time)
-            return get_sync_result(
-                result_payload=self.result_payload, sleep_time=self.sleep_time
-            )
+            return get_sync_result(result_payload=self.result_payload, sleep_time=self.sleep_time)
 
 
 class aioGeeTestTask:
@@ -115,9 +109,7 @@ class aioGeeTestTask:
 		:param kwargs: Параметры для подключения к прокси. Подробнее в официальной документации или примерe  - anticaptcha_examples/anticaptcha_gee_test_task.py
 		"""
         if sleep_time < 10:
-            raise ValueError(
-                f"Param `sleep_time` must be greater than 10. U set - {sleep_time}"
-            )
+            raise ValueError(f"Param `sleep_time` must be greater than 10. U set - {sleep_time}")
         self.sleep_time = sleep_time
 
         # Пайлоад для создания задачи
