@@ -61,7 +61,7 @@ class ReCaptchaV3TaskProxyless:
 		:param minScore: Определяет фильтр, по которому отбирается работник с нужным минимальным score.
 		:param pageAction: Значение параметра action, которое передается виджетом рекапчи в гугл,
                             и которое потом видит владелец сайта при проверке токена.
-		:param kwargs: Дополнительные параметры для `requests.post`, который отправляет даныйе на решение.
+		:param kwargs: Дополнительные параметры для `requests.post(....)`, который отправляет даныйе на решение.
 		:return: Возвращает ответ сервера в виде JSON-строки
 		"""
         if minScore not in MIN_SCORES:
