@@ -9,11 +9,6 @@ from .config import (
     app_key,
     get_result_url,
     create_task_url,
-    get_balance_url,
-    get_app_stats_url,
-    get_queue_status_url,
-    incorrect_recaptcha_url,
-    incorrect_imagecaptcha_url,
 )
 from .errors import ReadError, IdGetError, ParamError
 from .get_answer import get_sync_result, get_async_result
